# cs107-FinalProject
Final project deliverables

Group #5
Gregoire Baverez
Xinrong Yang
Aloysius Lim
Shivam Raval


## Badge travisci
[![Build Status](https://app.travis-ci.com/cs107-i-m-i-m/cs107-FinalProject.svg?token=RKxQRxaJdxdtKXuUyQLW&branch=main)](https://app.travis-ci.com/cs107-i-m-i-m/cs107-FinalProject)

## Badge Codecov
[![codecov](https://codecov.io/gh/cs107-i-m-i-m/cs107-FinalProject/branch/main/graph/badge.svg?token=JSLV57IM18)](https://codecov.io/gh/cs107-i-m-i-m/cs107-FinalProject)
